Python: module Configurations

Configurations (version 0.0.1) | index configurations.py

`This tool runs CLI scripts and displays output in a Web Interface.
This file implements a debug mode module to changes configurations
and reload modules.`

Classes
`` |  | builtins.object Reload
class Reload(builtins.object)
`` |  | Methods defined here: arguments(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads a argument configuration.` module(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads a module.` modules(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function adds new modules.` scripts(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads a script configuration.` server(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads the configuration.` web(environ: os._Environ, user: ~User, server: ~Server, name: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function reloads web files (JS, CSS and HTML).` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __annotations__ = {'accept_types': typing.Tuple[type], 'html': <class 'str'>, 'simple_types': typing.Tuple[type]} accept_types = (<class 'list'>, <class 'NoneType'>, <class 'str'>, <class 'bool'>, <class 'int'>, <class 'float'>) html = '\n <html><head><title>WebScripts Server co... }}\n </script></footer></body></html>\n ' simple_types = (<class 'NoneType'>, <class 'str'>, <class 'bool'>, <class 'int'>, <class 'float'>)

Data
`` |  | Dict = typing.Dict List = typing.List Server = ~Server Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool runs CLI scripts and displays output ...le to changes configurations\nand reload modules.\n' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' copyright = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' license = 'GPL-3.0 License'

Author
`` |  | Maurice Lambert